@@ -115,7 +115,7 @@ def interactive_loop(
             if command[0] in am.alias_names():
                 ap = AliasProcessor()
                 index = command_sequences.index()
-                ap.process(command[0], am, command_sequences)
+                ap.process(command, am, command_sequences)
                 command_sequences.rewind_to(index)
                 continue
 
@@ -189,15 +189,11 @@ def interactive_loop(
             #     continue
 
             if command_lower == "rescan":
-                if use_local_speaker_list:
-                    print("Using cached speaker list: no rescan performed")
-                else:
-                    logging.info("Full network rescan")
-                    speaker_cache().scan(reset=True)
-                    _print_speaker_list(use_local_speaker_list=use_local_speaker_list)
-                    _set_actions_and_commands_list(
-                        use_local_speaker_list=use_local_speaker_list
-                    )
+                _rescan(use_local_speaker_list=use_local_speaker_list)
+                continue
+
+            if command_lower == "rescan_max":
+                _rescan(use_local_speaker_list=use_local_speaker_list, max=True)
                 continue
 
             if command_lower == "push":
@@ -353,6 +349,7 @@ COMMANDS = [
     "pop",
     "push",
     "rescan",
+    "rescan_max",
     "set ",
     "single-keystroke",
     "sk",
@@ -421,6 +418,7 @@ This is SoCo-CLI interactive mode. Interactive commands are as follows:
     'push'      :   Save the current active speaker, and unset the active speaker.
     'rescan'    :   If your speaker doesn't appear in the 'speakers' list,
                     use this to perform a more comprehensive scan.
+    'rescan_max':   Try this if you're having trouble finding all your speakers.
     'set <spkr> :   Set the active speaker using its name.
                     Use quotes when needed for the speaker name, e.g.,
                     'set "Front Reception"'. Unambiguous partial, case-insensitive
@@ -479,14 +477,32 @@ def _restore_quotes(command):
 class AliasProcessor:
     def __init__(self):
         self._used_aliases = []
+        self._seq_number = 0
+        self._recurse_level = 0
+        self._command_count = 0
+        self._index = 0
+        self._command_list = []
 
-    def process(self, alias_name, am, command_list):
+    def process(self, command, am, command_list):
 
-        if alias_name in self._used_aliases:
-            print("Error: Alias loop detected ... stopping")
-            return False
+        alias_name = command[0]
+        alias_parms = command[1:]
+
+        self._command_list = command_list
+
+        for used_alias in self._used_aliases:
+            if used_alias[0] != self._recurse_level:
+                if used_alias[1] == self._seq_number and used_alias[2] == alias_name:
+                    # Recursion
+                    print("Error: Alias loop detected ... stopping".format(alias_name))
+                    self._remove_added_commands()
+                    return False
         else:
-            self._used_aliases.append(alias_name)
+            self._used_aliases.append(
+                (self._recurse_level, self._seq_number, alias_name)
+            )
+
+        self._recurse_level += 1
 
         alias_actions = am.action(alias_name)
         action_elements = shlex_split(alias_actions)
@@ -498,11 +514,13 @@ class AliasProcessor:
         logging.info("Unpacking the alias '{} -> '{}'".format(alias_name, sequences))
 
         index = command_list.index()
-        for sequence in sequences:
+        for idx, sequence in enumerate(sequences):
+            self._seq_number = idx
+            sequence = sequence + alias_parms
             # Recurse if the sequence is itself an alias
             if sequence[0] in am.alias_names():
                 logging.info("Recursively unpacking the alias '{}'".format(sequence[0]))
-                if self.process(sequence[0], am, command_list):
+                if self.process(sequence, am, command_list):
                     index = command_list.index()
                 else:
                     return False
@@ -513,5 +531,25 @@ class AliasProcessor:
                 logging.info("Inserting new sequence {} at {}".format(sequence, index))
                 command_list.insert(index, sequence)
                 index += 1
+                self._command_count += 1
+                self._index = index
 
         return True
+
+    def _remove_added_commands(self):
+        for _ in range(self._command_count):
+            cmd = self._command_list.pop_next()
+            logging.info("Removing command {}".format(cmd))
+
+
+def _rescan(use_local_speaker_list=False, max=False):
+    if use_local_speaker_list:
+        print("Using cached speaker list: no rescan performed")
+    elif max:
+        logging.info("Full network rescan at max strength (timeout = 10.0s)")
+        speaker_cache().scan(reset=True, scan_timeout_override=10.0)
+    else:
+        logging.info("Full network rescan")
+        speaker_cache().scan(reset=True)
+        _print_speaker_list(use_local_speaker_list=use_local_speaker_list)
+    _set_actions_and_commands_list(use_local_speaker_list=use_local_speaker_list)
